#include <Wire.h>
#include <DS1307.h>
#include <rgb_lcd.h>

rgb_lcd lcd;
DS1307 clock;//define a object of DS1307 class

int curNote = 0;
int length = 43;
char notes[] = "ccggaagffeeddcggffeedggffeedccggaagffeeddc";
int beats[] = {1,1,1,1,1,1,2,1,1,1,1,1,1,2,1,1,1,1,1,1,2,1,1,1,1,1,1,2,1,1,1,1,1,1,2,1,1,1,1,1,1,2,4};
int tempo = 300;

int magneticPin = 0;
int buzzerPin = 1;

String lastAccess;
bool wasOpen = true;

void setup() {
    pinMode(magneticPin, INPUT);
  
    lcd.begin(16, 2);
    lcd.setRGB(0,0,0);
    
    clock.begin();
    lastAccess = getTime();
}

void loop() {

  int magneticState = digitalRead(magneticPin);

  //if was closed and is now open, play warning
  if (magneticState == LOW && wasOpen == false){
    lastAccess = getTime();
    sendState("OPEN", lastAccess);
    wasOpen = true;
    
  //if was open and is now closed
  }else if (magneticState == HIGH && wasOpen == true){
    wasOpen = false;
    sendState("CLOSED", getTime());

  }

  playSong();
  lcd.setCursor(4,0);
  lcd.print(getTime());
  lcd.setCursor(0,1);
  lcd.print("last: " + lastAccess);
}


void sendState(String state, String loggedTime){
  int connected = Bean.getConnectionState();

  if(connected){
    String strToSend = loggedTime + "|" + state + "|" + Bean.getBatteryLevel();
    int strLength = strToSend.length();
    uint8_t buffString[strLength];
    
    for (int i=0; i< strLength; i++){
      buffString[i] = strToSend.charAt(i);
    }
    Bean.setScratchData(2, buffString, strLength);
  }
}

void playSong(){
  if(wasOpen){
    if(notes[curNote] == ' '){
      delay(beats[curNote] * tempo);
    }else{
      playNote(notes[curNote], beats[curNote] * tempo);
    }
    //pause between notes
    delay(tempo/3);
    curNote++;
    if(curNote >= length) curNote = 0;
  }
}

String getTime(){
    clock.getTime();
    
    String hour = (String)clock.hour;
    hour = ((hour.length() == 1) ? "0"+hour : hour);
    String minute = (String)clock.minute;
    minute = ((minute.length() == 1) ? "0"+minute : minute);
    String second = (String)clock.second;
    second = ((second.length() == 1) ? "0"+second : second);
    
    return (hour +":"+minute + ":"+second);
}

void playTone(int tone, int duration){
  for (long i = 0; i < duration * 1000L; i += tone*2){
    digitalWrite(buzzerPin, HIGH);
    delayMicroseconds(tone);
    digitalWrite(buzzerPin, LOW);
    delayMicroseconds(tone);
  }
}

void playNote(char note, int duration){
  char names[] = {'c','d','e','f','g','a','b','C'};
  int tones[] = {1915,1700,1519,1432,1275,1136,1014,956};

 //play the tone for the corresponding note
  for(int i=0;i<8;i++){
    if(names[i] == note){
      playTone(tones[i],duration);
    }
  }
}
